@@ -11,6 +11,5 @@ mod chrono;
 #[cfg(feature = "smallvec")]
 mod smallvec;
 
-pub fn err_invalid_data(text: &str) -> std::io::Error {
-    std::io::Error::new(std::io::ErrorKind::InvalidData, text.to_owned())
-}
+#[cfg(feature = "ipnet")]
+mod ipnet;
